# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.provisioning.v1 import catalog_group_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2


class CatalogGroupStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/create_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CreateCatalogGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
                )
        self.update_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/update_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.UpdateCatalogGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
                )
        self.delete_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/delete_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get_catalog_group = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_group',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.GetCatalogGroupRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
                )
        self.get_catalog_groups = channel.unary_unary(
                '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_groups',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupsInfo.FromString,
                )


class CatalogGroupServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalog_group(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalog_groups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CatalogGroupServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.create_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CreateCatalogGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.SerializeToString,
            ),
            'update_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.update_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.UpdateCatalogGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.SerializeToString,
            ),
            'delete_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get_catalog_group': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalog_group,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.GetCatalogGroupRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.SerializeToString,
            ),
            'get_catalog_groups': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalog_groups,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupsInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.provisioning.v1.CatalogGroup', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CatalogGroup(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/create_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CreateCatalogGroupRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/update_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.UpdateCatalogGroupRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/delete_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalog_group(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_group',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.GetCatalogGroupRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalog_groups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.CatalogGroup/get_catalog_groups',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupQuery.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2.CatalogGroupsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/plugin/collector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/inventory/plugin/collector.proto\x12\x1dspaceone.api.inventory.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"7\n\x0bInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"g\n\rVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x91\x01\n\x0e\x43ollectRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe9\x02\n\x0cResourceInfo\x12@\n\x05state\x18\x01 \x01(\x0e\x32\x31.spaceone.api.inventory.plugin.ResourceInfo.State\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12,\n\x0bmatch_rules\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08resource\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\"l\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0e\n\nINPROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x0b\n\x07\x46\x41ILURE\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\x12\x08\n\x04IDLE\x10\x07\"?\n\x13\x43ollectorVerifyInfo\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\nPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xa9\x02\n\tCollector\x12_\n\x04init\x12*.spaceone.api.inventory.plugin.InitRequest\x1a).spaceone.api.inventory.plugin.PluginInfo\"\x00\x12P\n\x06verify\x12,.spaceone.api.inventory.plugin.VerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x07\x63ollect\x12-.spaceone.api.inventory.plugin.CollectRequest\x1a+.spaceone.api.inventory.plugin.ResourceInfo\"\x00\x30\x01\x62\x06proto3')



_INITREQUEST = DESCRIPTOR.message_types_by_name['InitRequest']
_VERIFYREQUEST = DESCRIPTOR.message_types_by_name['VerifyRequest']
_COLLECTREQUEST = DESCRIPTOR.message_types_by_name['CollectRequest']
_RESOURCEINFO = DESCRIPTOR.message_types_by_name['ResourceInfo']
_COLLECTORVERIFYINFO = DESCRIPTOR.message_types_by_name['CollectorVerifyInfo']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_RESOURCEINFO_STATE = _RESOURCEINFO.enum_types_by_name['State']
InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYREQUEST,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.VerifyRequest)
  })
_sym_db.RegisterMessage(VerifyRequest)

CollectRequest = _reflection.GeneratedProtocolMessageType('CollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTREQUEST,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.CollectRequest)
  })
_sym_db.RegisterMessage(CollectRequest)

ResourceInfo = _reflection.GeneratedProtocolMessageType('ResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEINFO,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.ResourceInfo)
  })
_sym_db.RegisterMessage(ResourceInfo)

CollectorVerifyInfo = _reflection.GeneratedProtocolMessageType('CollectorVerifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORVERIFYINFO,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.CollectorVerifyInfo)
  })
_sym_db.RegisterMessage(CollectorVerifyInfo)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.inventory.plugin.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_COLLECTOR = DESCRIPTOR.services_by_name['Collector']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INITREQUEST._serialized_start=139
  _INITREQUEST._serialized_end=194
  _VERIFYREQUEST._serialized_start=196
  _VERIFYREQUEST._serialized_end=299
  _COLLECTREQUEST._serialized_start=302
  _COLLECTREQUEST._serialized_end=447
  _RESOURCEINFO._serialized_start=450
  _RESOURCEINFO._serialized_end=811
  _RESOURCEINFO_STATE._serialized_start=703
  _RESOURCEINFO_STATE._serialized_end=811
  _COLLECTORVERIFYINFO._serialized_start=813
  _COLLECTORVERIFYINFO._serialized_end=876
  _PLUGININFO._serialized_start=878
  _PLUGININFO._serialized_end=933
  _COLLECTOR._serialized_start=936
  _COLLECTOR._serialized_end=1233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/cloud_service_tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/inventory/v1/cloud_service_tag.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x9c\x01\n\x14\x43loudServiceTagQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63loud_service_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"\x92\x01\n\x13\x43loudServiceTagInfo\x12\x18\n\x10\x63loud_service_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"l\n\x14\x43loudServiceTagsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.CloudServiceTagInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"}\n\x18\x43loudServiceTagStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x03 \x01(\t2\xd7\x02\n\x0f\x43loudServiceTag\x12\xbd\x01\n\x04list\x12/.spaceone.api.inventory.v1.CloudServiceTagQuery\x1a/.spaceone.api.inventory.v1.CloudServiceTagsInfo\"S\x82\xd3\xe4\x93\x02M\x12 /inventory/v1/cloud-service-tagsZ)\"\'/inventory/v1/cloud-service-tags/search\x12\x83\x01\n\x04stat\x12\x33.spaceone.api.inventory.v1.CloudServiceTagStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/cloud-service-tags/statb\x06proto3')



_CLOUDSERVICETAGQUERY = DESCRIPTOR.message_types_by_name['CloudServiceTagQuery']
_CLOUDSERVICETAGINFO = DESCRIPTOR.message_types_by_name['CloudServiceTagInfo']
_CLOUDSERVICETAGSINFO = DESCRIPTOR.message_types_by_name['CloudServiceTagsInfo']
_CLOUDSERVICETAGSTATQUERY = DESCRIPTOR.message_types_by_name['CloudServiceTagStatQuery']
CloudServiceTagQuery = _reflection.GeneratedProtocolMessageType('CloudServiceTagQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETAGQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTagQuery)
  })
_sym_db.RegisterMessage(CloudServiceTagQuery)

CloudServiceTagInfo = _reflection.GeneratedProtocolMessageType('CloudServiceTagInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETAGINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTagInfo)
  })
_sym_db.RegisterMessage(CloudServiceTagInfo)

CloudServiceTagsInfo = _reflection.GeneratedProtocolMessageType('CloudServiceTagsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETAGSINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTagsInfo)
  })
_sym_db.RegisterMessage(CloudServiceTagsInfo)

CloudServiceTagStatQuery = _reflection.GeneratedProtocolMessageType('CloudServiceTagStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETAGSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTagStatQuery)
  })
_sym_db.RegisterMessage(CloudServiceTagStatQuery)

_CLOUDSERVICETAG = DESCRIPTOR.services_by_name['CloudServiceTag']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDSERVICETAG.methods_by_name['list']._options = None
  _CLOUDSERVICETAG.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /inventory/v1/cloud-service-tagsZ)\"\'/inventory/v1/cloud-service-tags/search'
  _CLOUDSERVICETAG.methods_by_name['stat']._options = None
  _CLOUDSERVICETAG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/cloud-service-tags/stat'
  _CLOUDSERVICETAGQUERY._serialized_start=175
  _CLOUDSERVICETAGQUERY._serialized_end=331
  _CLOUDSERVICETAGINFO._serialized_start=334
  _CLOUDSERVICETAGINFO._serialized_end=480
  _CLOUDSERVICETAGSINFO._serialized_start=482
  _CLOUDSERVICETAGSINFO._serialized_end=590
  _CLOUDSERVICETAGSTATQUERY._serialized_start=592
  _CLOUDSERVICETAGSTATQUERY._serialized_end=717
  _CLOUDSERVICETAG._serialized_start=720
  _CLOUDSERVICETAG._serialized_end=1063
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import budget_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2


class BudgetStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/create',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.CreateBudgetRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/update',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.UpdateBudgetRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
                )
        self.set_notification = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/set_notification',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.SetBudgetNotificationRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/delete',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.GetBudgetRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Budget/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class BudgetServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Budget. When creating a Budget, it should be set for a specific ProjectGroup or Project. The budgeted amount and date of the `planned_limits` should be specified on a monthly or yearly basis.
        request_example: >-
        {
        "name": "Cloudforet-Budget",
        "planned_limits": [{"date": "2022-01", "limit": 1000.0},
        {"date": "2022-02", "limit": 1100.0},
        {"date": "2022-03", "limit": 1200.0},
        {"date": "2022-04", "limit": 1300.0},
        {"date": "2022-05", "limit": 1400.0},
        {"date": "2022-06", "limit": 1500.0},
        {"date": "2022-07", "limit": 1600.0},
        {"date": "2022-08", "limit": 1700.0},
        {"date": "2022-09", "limit": 1800.0},
        {"date": "2022-10", "limit": 1900.0},
        {"date": "2022-11", "limit": 2000.0},
        {"date": "2022-12", "limit": 2100.0}],
        "time_unit": "MONTHLY",
        "start": "2022-01",
        "end": "2022-12",
        "project_group_id": "pg-812c90990877"
        }
        response_example: >-
        {
        "budget_id": "budget-d51b6b6a9910",
        "name": "Cloudforet-Budget",
        "limit": 18600.0,
        "planned_limits": [
        {
        "date": "2022-01",
        "limit": 1000.0
        },
        {
        "date": "2022-02",
        "limit": 1100.0
        },
        {
        "date": "2022-03",
        "limit": 1200.0
        },
        {
        "date": "2022-04",
        "limit": 1300.0
        },
        {
        "date": "2022-05",
        "limit": 1400.0
        },
        {
        "date": "2022-06",
        "limit": 1500.0
        },
        {
        "date": "2022-07",
        "limit": 1600.0
        },
        {
        "date": "2022-08",
        "limit": 1700.0
        },
        {
        "date": "2022-09",
        "limit": 1800.0
        },
        {
        "date": "2022-10",
        "limit": 1900.0
        },
        {
        "date": "2022-11",
        "limit": 2000.0
        },
        {
        "date": "2022-12",
        "limit": 2100.0
        }
        ],
        "total_usage_usd_cost": 43412.45,
        "time_unit": "MONTHLY",
        "start": "2022-01",
        "end": "2022-12",
        "tags": {},
        "project_group_id": "pg-812c90990877",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-18T09:30:56.901Z",
        "updated_at": "2022-07-18T09:30:56.901Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Budget. You can make changes in the budgeted amount of the time period specified while creating the resource.
        request_example: >-
        {
        "budget_id": "budget-d51b6b6a9910",
        "name": "Cloudforet-Budget-test", "limit": 15000.0,
        "planned_limits": [{"date": "2022-01", "limit": 500.0},
        {"date": "2022-02", "limit": 500.0},
        {"date": "2022-03", "limit": 500.0},
        {"date": "2022-04", "limit": 500.0},
        {"date": "2022-05", "limit": 500.0},
        {"date": "2022-06", "limit": 500.0},
        {"date": "2022-07", "limit": 500.0},
        {"date": "2022-08", "limit": 500.0},
        {"date": "2022-09", "limit": 500.0}],
        "end": "2022-12",
        "tags": {}
        }
        response_example: >-
        {
        "budget_id": "budget-d51b6b6a9910",
        "name": "Cloudforet-Budget-test",
        "limit": 15000.0,
        "planned_limits": [
        {
        "date": "2022-01",
        "limit": 500.0
        },
        {
        "date": "2022-02",
        "limit": 500.0
        },
        {
        "date": "2022-03",
        "limit": 500.0
        },
        {
        "date": "2022-04",
        "limit": 500.0
        },
        {
        "date": "2022-05",
        "limit": 500.0
        },
        {
        "date": "2022-06",
        "limit": 500.0
        },
        {
        "date": "2022-07",
        "limit": 500.0
        },
        {
        "date": "2022-08",
        "limit": 500.0
        },
        {
        "date": "2022-09",
        "limit": 500.0
        }
        ],
        "total_usage_usd_cost": 43642.49,
        "time_unit": "MONTHLY",
        "start": "2022-01",
        "end": "2022-12",
        "tags": {},
        "project_group_id": "pg-812c90990877",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-18T09:30:56.901Z",
        "updated_at": "2022-07-18T09:30:56.901Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_notification(self, request, context):
        """
        desc: Sets a notification on a specific Budget. Sets a threshold on the budget, and if the cost exceeds the threshold, a notification is raised.
        request_example: >-
        {
        "budget_id": "budget-4c8606da4521",
        "notifications": [
        {
        "threshold": 20.0,
        "unit": "PERCENT",
        "notification_type": "CRITICAL"
        },
        {
        "threshold": 1000.0,
        "unit": "ACTUAL_COST",
        "notification_type": "WARNING"
        }
        ]
        }
        response_example: >-
        {
        "budget_id": "budget-4c8606da4521",
        "name": "Cloudforet-Budget-test2",
        "limit": 5000.0,
        "time_unit": "TOTAL",
        "start": "2022-01",
        "end": "2022-12",
        "notifications": [
        {
        "threshold": 20.0,
        "unit": "PERCENT",
        "notification_type": "CRITICAL"
        },
        {
        "threshold": 1000.0,
        "unit": "ACTUAL_COST",
        "notification_type": "WARNING"
        }
        ],
        "tags": {},
        "project_id": "project-52a423012d5e",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T04:31:10.314Z",
        "updated_at": "2022-07-19T04:31:10.314Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Budget. You must specify the `budget_id` of the Budget to delete.
        request_example: >-
        {
        "budget_id": "budget-d51b6b6a9910"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Budget. Prints detailed information about the Budget, including `planned_limits` of the project group or project for the pre-defined period.
        request_example: >-
        {
        "budget_id": "budget-d51b6b6a9910"
        }
        response_example: >-
        {
        "budget_id": "budget-d51b6b6a9910",
        "name": "Cloudforet-Budget",
        "limit": 18600.0,
        "planned_limits": [
        {
        "date": "2022-01",
        "limit": 1000.0
        },
        {
        "date": "2022-02",
        "limit": 1100.0
        },
        {
        "date": "2022-03",
        "limit": 1200.0
        },
        {
        "date": "2022-04",
        "limit": 1300.0
        },
        {
        "date": "2022-05",
        "limit": 1400.0
        },
        {
        "date": "2022-06",
        "limit": 1500.0
        },
        {
        "date": "2022-07",
        "limit": 1600.0
        },
        {
        "date": "2022-08",
        "limit": 1700.0
        },
        {
        "date": "2022-09",
        "limit": 1800.0
        },
        {
        "date": "2022-10",
        "limit": 1900.0
        },
        {
        "date": "2022-11",
        "limit": 2000.0
        },
        {
        "date": "2022-12",
        "limit": 2100.0
        }
        ],
        "total_usage_usd_cost": 43412.45,
        "time_unit": "MONTHLY",
        "start": "2022-01",
        "end": "2022-12",
        "tags": {},
        "project_group_id": "pg-812c90990877",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-18T09:30:56.901Z",
        "updated_at": "2022-07-18T09:30:56.901Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Budgets. You can use a query to get a filtered list of Budgets.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "budget_id": "budget-409e33836ea2",
        "name": "Budget 2 - Monthly",
        "limit": 18600.0,
        "planned_limits": [
        {
        "date": "2022-01",
        "limit": 1000.0
        },
        {
        "date": "2022-02",
        "limit": 1100.0
        },
        {
        "date": "2022-03",
        "limit": 1200.0
        },
        {
        "date": "2022-04",
        "limit": 1300.0
        },
        {
        "date": "2022-05",
        "limit": 1400.0
        },
        {
        "date": "2022-06",
        "limit": 1500.0
        },
        {
        "date": "2022-07",
        "limit": 1600.0
        },
        {
        "date": "2022-08",
        "limit": 1700.0
        },
        {
        "date": "2022-09",
        "limit": 1800.0
        },
        {
        "date": "2022-10",
        "limit": 1900.0
        },
        {
        "date": "2022-11",
        "limit": 2000.0
        },
        {
        "date": "2022-12",
        "limit": 2100.0
        }
        ],
        "total_usage_usd_cost": 43412.45,
        "time_unit": "MONTHLY",
        "start": "2022-01",
        "end": "2022-12",
        "tags": {},
        "project_group_id": "pg-812c90990877",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-12T06:09:56.917Z",
        "updated_at": "2022-04-12T06:09:56.917Z"
        }
        ],
        "total_count": 6
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BudgetServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.CreateBudgetRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.UpdateBudgetRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.SerializeToString,
            ),
            'set_notification': grpc.unary_unary_rpc_method_handler(
                    servicer.set_notification,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.SetBudgetNotificationRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.GetBudgetRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.Budget', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Budget(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/create',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.CreateBudgetRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/update',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.UpdateBudgetRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_notification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/set_notification',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.SetBudgetNotificationRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/delete',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.GetBudgetRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Budget/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__pb2.BudgetStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/price_list/v1/risp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/price_list/v1/risp.proto\x12\x1aspaceone.api.price_list.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xcf\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x11\n\tsecret_id\x18\x07 \x01(\t\x12H\n\x0cupgrade_mode\x18\x08 \x01(\x0e\x32\x32.spaceone.api.price_list.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xd7\x01\n\x13RegisterRispRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12K\n\trisp_type\x18\x02 \x01(\x0e\x32\x38.spaceone.api.price_list.v1.RegisterRispRequest.RispType\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x08RispType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\x97\x01\n\x11UpdateRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xfe\x01\n\x17UpdateRispPluginRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12U\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32?.spaceone.api.price_list.v1.UpdateRispPluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"^\n\x0fSyncRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x18\n\x10no_preload_cache\x18\x03 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"1\n\x0bRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetRispRequest\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xfc\x01\n\tRispQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07risp_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x41\n\trisp_type\x18\x05 \x01(\x0e\x32..spaceone.api.price_list.v1.RispQuery.RispType\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x08RispType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xae\x04\n\x08RispInfo\x12\x0f\n\x07risp_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.spaceone.api.price_list.v1.RispInfo.State\x12@\n\trisp_type\x18\x04 \x01(\x0e\x32-.spaceone.api.price_list.v1.RispInfo.RispType\x12\x10\n\x08provider\x18\x05 \x01(\t\x12;\n\x0bplugin_info\x18\x06 \x01(\x0b\x32&.spaceone.api.price_list.v1.PluginInfo\x12)\n\x08template\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rcost_tag_keys\x18\t \x03(\t\x12!\n\x19\x63ost_additional_info_keys\x18\n \x03(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x1c\n\x14last_synchronized_at\x18\x16 \x01(\t\"2\n\x05State\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"2\n\x08RispType\x12\r\n\tTYPE_NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"W\n\tRispsInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.price_list.v1.RispInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rRispStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x83\x06\n\x04Risp\x12~\n\x08register\x12/.spaceone.api.price_list.v1.RegisterRispRequest\x1a$.spaceone.api.price_list.v1.RispInfo\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/price-list/v1/risp\x12\x84\x01\n\x06update\x12-.spaceone.api.price_list.v1.UpdateRispRequest\x1a$.spaceone.api.price_list.v1.RispInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/price-list/v1/risp/{risp_id}\x12t\n\nderegister\x12\'.spaceone.api.price_list.v1.RispRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/price-list/v1/risp/{risp_id}\x12~\n\x03get\x12*.spaceone.api.price_list.v1.GetRispRequest\x1a$.spaceone.api.price_list.v1.RispInfo\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/price-list/v1/risp/{risp_id}\x12\x8f\x01\n\x04list\x12%.spaceone.api.price_list.v1.RispQuery\x1a%.spaceone.api.price_list.v1.RispsInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x13/price-list/v1/rispZ\x1c\"\x1a/price-list/v1/risp/search\x12l\n\x04stat\x12).spaceone.api.price_list.v1.RispStatQuery\x1a\x17.google.protobuf.Struct\" \x82\xd3\xe4\x93\x02\x1a\"\x18/price-list/v1/risp/statb\x06proto3')



_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_REGISTERRISPREQUEST = DESCRIPTOR.message_types_by_name['RegisterRispRequest']
_UPDATERISPREQUEST = DESCRIPTOR.message_types_by_name['UpdateRispRequest']
_UPDATERISPPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateRispPluginRequest']
_SYNCRISPREQUEST = DESCRIPTOR.message_types_by_name['SyncRispRequest']
_RISPREQUEST = DESCRIPTOR.message_types_by_name['RispRequest']
_GETRISPREQUEST = DESCRIPTOR.message_types_by_name['GetRispRequest']
_RISPQUERY = DESCRIPTOR.message_types_by_name['RispQuery']
_RISPINFO = DESCRIPTOR.message_types_by_name['RispInfo']
_RISPSINFO = DESCRIPTOR.message_types_by_name['RispsInfo']
_RISPSTATQUERY = DESCRIPTOR.message_types_by_name['RispStatQuery']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_REGISTERRISPREQUEST_RISPTYPE = _REGISTERRISPREQUEST.enum_types_by_name['RispType']
_UPDATERISPPLUGINREQUEST_UPGRADEMODE = _UPDATERISPPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_RISPQUERY_RISPTYPE = _RISPQUERY.enum_types_by_name['RispType']
_RISPINFO_STATE = _RISPINFO.enum_types_by_name['State']
_RISPINFO_RISPTYPE = _RISPINFO.enum_types_by_name['RispType']
PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

RegisterRispRequest = _reflection.GeneratedProtocolMessageType('RegisterRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERRISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RegisterRispRequest)
  })
_sym_db.RegisterMessage(RegisterRispRequest)

UpdateRispRequest = _reflection.GeneratedProtocolMessageType('UpdateRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.UpdateRispRequest)
  })
_sym_db.RegisterMessage(UpdateRispRequest)

UpdateRispPluginRequest = _reflection.GeneratedProtocolMessageType('UpdateRispPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERISPPLUGINREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.UpdateRispPluginRequest)
  })
_sym_db.RegisterMessage(UpdateRispPluginRequest)

SyncRispRequest = _reflection.GeneratedProtocolMessageType('SyncRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCRISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.SyncRispRequest)
  })
_sym_db.RegisterMessage(SyncRispRequest)

RispRequest = _reflection.GeneratedProtocolMessageType('RispRequest', (_message.Message,), {
  'DESCRIPTOR' : _RISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispRequest)
  })
_sym_db.RegisterMessage(RispRequest)

GetRispRequest = _reflection.GeneratedProtocolMessageType('GetRispRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRISPREQUEST,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.GetRispRequest)
  })
_sym_db.RegisterMessage(GetRispRequest)

RispQuery = _reflection.GeneratedProtocolMessageType('RispQuery', (_message.Message,), {
  'DESCRIPTOR' : _RISPQUERY,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispQuery)
  })
_sym_db.RegisterMessage(RispQuery)

RispInfo = _reflection.GeneratedProtocolMessageType('RispInfo', (_message.Message,), {
  'DESCRIPTOR' : _RISPINFO,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispInfo)
  })
_sym_db.RegisterMessage(RispInfo)

RispsInfo = _reflection.GeneratedProtocolMessageType('RispsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RISPSINFO,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispsInfo)
  })
_sym_db.RegisterMessage(RispsInfo)

RispStatQuery = _reflection.GeneratedProtocolMessageType('RispStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RISPSTATQUERY,
  '__module__' : 'spaceone.api.price_list.v1.risp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.price_list.v1.RispStatQuery)
  })
_sym_db.RegisterMessage(RispStatQuery)

_RISP = DESCRIPTOR.services_by_name['Risp']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RISP.methods_by_name['register']._options = None
  _RISP.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\025\"\023/price-list/v1/risp'
  _RISP.methods_by_name['update']._options = None
  _RISP.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\037\032\035/price-list/v1/risp/{risp_id}'
  _RISP.methods_by_name['deregister']._options = None
  _RISP.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002\037*\035/price-list/v1/risp/{risp_id}'
  _RISP.methods_by_name['get']._options = None
  _RISP.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\037\022\035/price-list/v1/risp/{risp_id}'
  _RISP.methods_by_name['list']._options = None
  _RISP.methods_by_name['list']._serialized_options = b'\202\323\344\223\0023\022\023/price-list/v1/rispZ\034\"\032/price-list/v1/risp/search'
  _RISP.methods_by_name['stat']._options = None
  _RISP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\032\"\030/price-list/v1/risp/stat'
  _PLUGININFO._serialized_start=193
  _PLUGININFO._serialized_end=528
  _PLUGININFO_UPGRADEMODE._serialized_start=483
  _PLUGININFO_UPGRADEMODE._serialized_end=528
  _REGISTERRISPREQUEST._serialized_start=531
  _REGISTERRISPREQUEST._serialized_end=746
  _REGISTERRISPREQUEST_RISPTYPE._serialized_start=701
  _REGISTERRISPREQUEST_RISPTYPE._serialized_end=746
  _UPDATERISPREQUEST._serialized_start=749
  _UPDATERISPREQUEST._serialized_end=900
  _UPDATERISPPLUGINREQUEST._serialized_start=903
  _UPDATERISPPLUGINREQUEST._serialized_end=1157
  _UPDATERISPPLUGINREQUEST_UPGRADEMODE._serialized_start=483
  _UPDATERISPPLUGINREQUEST_UPGRADEMODE._serialized_end=528
  _SYNCRISPREQUEST._serialized_start=1159
  _SYNCRISPREQUEST._serialized_end=1253
  _RISPREQUEST._serialized_start=1255
  _RISPREQUEST._serialized_end=1304
  _GETRISPREQUEST._serialized_start=1306
  _GETRISPREQUEST._serialized_end=1372
  _RISPQUERY._serialized_start=1375
  _RISPQUERY._serialized_end=1627
  _RISPQUERY_RISPTYPE._serialized_start=701
  _RISPQUERY_RISPTYPE._serialized_end=746
  _RISPINFO._serialized_start=1630
  _RISPINFO._serialized_end=2188
  _RISPINFO_STATE._serialized_start=2086
  _RISPINFO_STATE._serialized_end=2136
  _RISPINFO_RISPTYPE._serialized_start=2138
  _RISPINFO_RISPTYPE._serialized_end=2188
  _RISPSINFO._serialized_start=2190
  _RISPSINFO._serialized_end=2277
  _RISPSTATQUERY._serialized_start=2279
  _RISPSTATQUERY._serialized_end=2367
  _RISP._serialized_start=2370
  _RISP._serialized_end=3141
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.identity.v1 import token_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2


class TokenStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.issue = channel.unary_unary(
                '/spaceone.api.identity.v1.Token/issue',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.IssueTokenRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.TokenInfo.FromString,
                )
        self.refresh = channel.unary_unary(
                '/spaceone.api.identity.v1.Token/refresh',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.TokenInfo.FromString,
                )


class TokenServicer(object):
    """Missing associated documentation comment in .proto file."""

    def issue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def refresh(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'issue': grpc.unary_unary_rpc_method_handler(
                    servicer.issue,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.IssueTokenRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.TokenInfo.SerializeToString,
            ),
            'refresh': grpc.unary_unary_rpc_method_handler(
                    servicer.refresh,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.TokenInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.identity.v1.Token', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Token(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def issue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Token/issue',
            spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.IssueTokenRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.TokenInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def refresh(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Token/refresh',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_token__pb2.TokenInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import collector_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2


class CollectorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/create',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CreateCollectorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/update',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdateCollectorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/update_plugin',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdatePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
                )
        self.verify_plugin = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/verify_plugin',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.VerifyPluginRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.GetCollectorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/enable',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/disable',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.collect = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/collect',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.JobInfo.FromString,
                )
        self.add_schedule = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/add_schedule',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CreateScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.FromString,
                )
        self.get_schedule = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/get_schedule',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.FromString,
                )
        self.update_schedule = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/update_schedule',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdateScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.FromString,
                )
        self.delete_schedule = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/delete_schedule',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.DeleteScheduleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.list_schedules = channel.unary_unary(
                '/spaceone.api.inventory.v1.Collector/list_schedules',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.SchedulesInfo.FromString,
                )


class CollectorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Collector with information of the plugin to use. Information of the plugin includes `version`, `provider`, and `upgrade_mode`.
        request_example: >-
        {
        "name": "AWS Collector",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13",
        "options": {},
        "provider": "aws",
        "metadata": {
        "filter_format": [],
        "supported_schedules": [
        "hours"
        ],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "supported_features": [
        "garbage_collection"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "priority": 1,
        "tags": {
        "type": "test"
        },
        "is_public": true
        }
        response_example: >-
        {
        "collector_id": "collector-2c0847644f39",
        "name": "AWS Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_schedules": [
        "hours"
        ],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "filter_format": [],
        "supported_features": [
        "garbage_collection"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "priority": 1,
        "tags": {
        "type": "test"
        },
        "created_at": "2022-06-17T06:33:27.195Z",
        "domain_id": "domain-58010aa2e451",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Collector. You can make changes in Collector settings, including `name` and `tags`.
        request_example: >-
        {
        "collector_id": "collector-2c0847644f39",
        "name": "New AWS Collector",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.14.0",
        "provider": "aws",
        "upgrade_mode": "MANUAL"
        },
        "priority": 10,
        "tags": {
        "a": "b"
        }
        }
        response_example: >-
        {
        "collector_id": "collector-2c0847644f39",
        "name": "New AWS Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.14.0",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_schedules": [
        "hours"
        ],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "filter_format": [],
        "supported_features": [
        "garbage_collection"
        ]
        },
        "upgrade_mode": "MANUAL"
        },
        "priority": 10,
        "tags": {
        "a": "b"
        },
        "created_at": "2022-06-17T06:33:27.195Z",
        "domain_id": "domain-58010aa2e451",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """
        desc: Updates the plugin of a specific Collector. This method resets the plugin data in the Collector to update the `metadata`.
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify_plugin(self, request, context):
        """
        desc: Verifies the plugin of a specific Collector. This method validates the plugin data, `version` and `endpoint`.
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Collector. You must specify the `collector_id` of the Collector to delete.
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Collector. Prints detailed information about the Collector, including its state, basic information, and the plugin information used for cloud resource collection.
        request_example: >-
        {
        "collector_id": "collector-f2e4e9cc7f21"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific Collector. By enabling a Collector, you can communicate with a plugin used for collection.
        request_example: >-
        {
        "collector_id": "collector-f2e4e9cc7f21"
        }
        response_example: >-
        {
        "collector_id": "collector-f2e4e9cc7f21",
        "name": "AWS Cloud Service Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.14.10",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_schedules": [
        "hours"
        ],
        "filter_format": [],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "supported_features": [
        "garbage_collection"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "priority": 10,
        "tags": {},
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true,
        "created_at": "2021-03-08T06:49:27.876Z",
        "last_collected_at": "2022-06-17T06:00:07.162Z",
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific Collector. By disabling a Collector, you cannot communicate with a plugin used for collection.
        request_example: >-
        {
        "collector_id": "collector-f2e4e9cc7f21"
        }
        response_example: >-
        {
        "collector_id": "collector-f2e4e9cc7f21",
        "name": "AWS Cloud Service Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.14.10",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_schedules": [
        "hours"
        ],
        "filter_format": [],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "supported_features": [
        "garbage_collection"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "priority": 10,
        "tags": {},
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true,
        "created_at": "2021-03-08T06:49:27.876Z",
        "last_collected_at": "2022-06-17T06:00:07.162Z",
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Collectors. You can use a query to get a filtered list of Collectors.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "job_id": "job-3b124006c2d2",
        "status": "SUCCESS",
        "filter": {},
        "total_tasks": 2,
        "collector_info": {
        "collector_id": "collector-accd02663b3d",
        "name": "openstack-collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-openstack-inven-collector",
        "version": "0.4.2.20220616.134758"
        },
        "provider": "openstack",
        "capability": {
        "supported_schema": [
        "openstack_credentials"
        ]
        },
        "is_public": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-17T08:00:01.225Z",
        "updated_at": "2022-06-17T08:00:01.225Z",
        "finished_at": "2022-06-17T08:00:15.197Z"
        },
        {
        "job_id": "job-587a3d3b4db3",
        "status": "SUCCESS",
        "filter": {},
        "total_tasks": 3,
        "collector_info": {
        "collector_id": "collector-2c0847644f39",
        "name": "AWS stat-kwon Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13.20220610.143142"
        },
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-17T08:00:00.407Z",
        "updated_at": "2022-06-17T08:00:00.407Z",
        "finished_at": "2022-06-17T08:07:32.023Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def collect(self, request, context):
        """
        desc: ''
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_schedule(self, request, context):
        """
        desc: Adds a schedule to a specific Collector. When specifying the time to collect, the schedule is assigned in units of one hour.The specified schedule is applied every day.
        request_example: >-
        {
        "collector_id": "collector-2c0847644f39",
        "name": "regular collection",
        "schedule": {
        "hours": [16, 18, 20, 22, 0]
        }
        }
        response_example: >-
        {
        "schedule_id": "sched-dfb2f6ef84bc",
        "name": "regular collection",
        "collect_mode": "ALL",
        "schedule": {
        "hours": [
        16,
        18,
        20,
        22,
        0
        ]
        },
        "created_at": "2022-06-17T07:12:07.374Z",
        "collector_info": {
        "collector_id": "collector-2c0847644f39",
        "name": "AWS stat-kwon Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13.20220610.143142",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "supported_features": [
        "garbage_collection"
        ],
        "filter_format": [],
        "supported_schedules": [
        "hours"
        ]
        },
        "upgrade_mode": "MANUAL"
        },
        "priority": 10,
        "tags": {
        "a": "b"
        },
        "created_at": "2022-06-17T06:33:27.195Z",
        "domain_id": "domain-58010aa2e451",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        },
        "filter": {}
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_schedule(self, request, context):
        """
        desc: Gets a specific schedule set in a specific Collector. You must specify the `collector_id` of the Collector and the `schedule_id` of the schedule.
        request_example: >-
        {
        "collector_id": "collector-2c0847644f39",
        "schedule_id": "sched-dfb2f6ef84bc"
        }
        response_example: >-
        {
        "schedule_id": "sched-dfb2f6ef84bc",
        "name": "regular collection",
        "collect_mode": "ALL",
        "schedule": {
        "hours": [
        16,
        18,
        20,
        22,
        0
        ]
        },
        "created_at": "2022-06-17T07:12:07.374Z",
        "collector_info": {
        "collector_id": "collector-2c0847644f39",
        "name": "AWS stat-kwon Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13.20220610.143142",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_features": [
        "garbage_collection"
        ],
        "filter_format": [],
        "supported_schedules": [
        "hours"
        ],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ]
        },
        "upgrade_mode": "MANUAL"
        },
        "priority": 10,
        "tags": {
        "a": "b"
        },
        "created_at": "2022-06-17T06:33:27.195Z",
        "domain_id": "domain-58010aa2e451",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        },
        "filter": {}
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_schedule(self, request, context):
        """
        desc: Updates a specific schedule of the Collector. You can make changes in schedule settings, including `name` and collection time.
        request_example: >-
        {
        "schedule_id": "sched-dfb2f6ef84bc",
        "collector_id": "collector-2c0847644f39",
        "name": "regular collection",
        "collect_mode": "ALL",
        "schedule": {
        "hours": [2, 4, 6, 8, 0]
        },
        "filter": {}
        }
        response_example: >-
        {
        "schedule_id": "sched-dfb2f6ef84bc",
        "name": "regular collection",
        "collect_mode": "ALL",
        "schedule": {
        "hours": [
        2,
        4,
        6,
        8,
        0
        ]
        },
        "created_at": "2022-06-17T07:12:07.374Z",
        "collector_info": {
        "collector_id": "collector-2c0847644f39",
        "name": "AWS stat-kwon Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13.20220610.143142",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_features": [
        "garbage_collection"
        ],
        "supported_schedules": [
        "hours"
        ],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ],
        "filter_format": []
        },
        "upgrade_mode": "MANUAL"
        },
        "priority": 10,
        "tags": {
        "a": "b"
        },
        "created_at": "2022-06-17T06:33:27.195Z",
        "last_collected_at": "2022-06-17T08:00:00.793Z",
        "domain_id": "domain-58010aa2e451",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        },
        "filter": {}
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_schedule(self, request, context):
        """
        desc: Deletes a specific schedule of the Collector. You must specify the `schedule_id` of the schedule to delete.
        request_example: >-
        {
        "schedule_id": "sched-dfb2f6ef84bc",
        "collector_id": "collector-2c0847644f39"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_schedules(self, request, context):
        """
        desc: Gets a list of all schedules set in a specific Collector. You must specify the `collector_id` of the Collector to get the schedule from.
        request_example: >-
        {
        "collector_id": "collector-f2e4e9cc7f21"
        }
        response_example: >-
        {
        "results": [
        {
        "schedule_id": "sched-572819cabe90",
        "name": "daily",
        "collect_mode": "ALL",
        "schedule": {
        "hours": [
        15,
        16,
        18,
        21,
        0,
        3,
        4,
        6,
        9,
        12
        ]
        },
        "created_at": "2021-03-13T14:32:46.137Z",
        "collector_info": {
        "collector_id": "collector-f2e4e9cc7f21",
        "name": "AWS Cloud Service Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13.20220610.143142",
        "options": {},
        "provider": "aws",
        "metadata": {
        "supported_features": [
        "garbage_collection"
        ],
        "supported_schedules": [
        "hours"
        ],
        "filter_format": [],
        "supported_resource_type": [
        "inventory.CloudService",
        "inventory.CloudServiceType",
        "inventory.Region"
        ]
        },
        "upgrade_mode": "AUTO"
        },
        "priority": 10,
        "tags": {},
        "created_at": "2021-03-08T06:49:27.876Z",
        "last_collected_at": "2022-06-17T06:00:07.162Z",
        "domain_id": "domain-58010aa2e451",
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        },
        "filter": {}
        }
        ],
        "total_count": 1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CollectorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CreateCollectorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdateCollectorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdatePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.SerializeToString,
            ),
            'verify_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.verify_plugin,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.VerifyPluginRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.GetCollectorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'collect': grpc.unary_unary_rpc_method_handler(
                    servicer.collect,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.JobInfo.SerializeToString,
            ),
            'add_schedule': grpc.unary_unary_rpc_method_handler(
                    servicer.add_schedule,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CreateScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.SerializeToString,
            ),
            'get_schedule': grpc.unary_unary_rpc_method_handler(
                    servicer.get_schedule,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.SerializeToString,
            ),
            'update_schedule': grpc.unary_unary_rpc_method_handler(
                    servicer.update_schedule,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdateScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.SerializeToString,
            ),
            'delete_schedule': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_schedule,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.DeleteScheduleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'list_schedules': grpc.unary_unary_rpc_method_handler(
                    servicer.list_schedules,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.SchedulesInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.Collector', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Collector(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/create',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CreateCollectorRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/update',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdateCollectorRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/update_plugin',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdatePluginRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/verify_plugin',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.VerifyPluginRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.GetCollectorRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/enable',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/disable',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectorStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def collect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/collect',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CollectRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add_schedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/add_schedule',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.CreateScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_schedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/get_schedule',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_schedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/update_schedule',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.UpdateScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_schedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/delete_schedule',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.DeleteScheduleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_schedules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Collector/list_schedules',
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.ScheduleQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.SchedulesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import escalation_policy_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2


class EscalationPolicyStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.CreateEscalationPolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.UpdateEscalationPolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
                )
        self.set_default = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/set_default',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/delete',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.GetEscalationPolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPoliciesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.EscalationPolicy/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class EscalationPolicyServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new EscalationPolicy. When creating an EscalationPolicy, if the project_id is assigned, the EscalationPolicy is applied to the Project with the same project_id. If an EscalationPolicy is set as a global policy, all Projects in the same domain can apply the policy.
        request_example: >-
        {
        "name": "es-test",
        "rules": [{"notification_level": "LV1", "escalate_minutes": 30},
        {"notification_level": "LV2", "escalate_minutes": 30}],
        "repeat_count": 2,
        "finish_condition": "ACKNOWLEDGED",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "escalation_policy_id": "ep-526e536fdca9",
        "name": "es-test",
        "rules": [
        {
        "notification_level": "LV1",
        "escalate_minutes": 30
        },
        {
        "notification_level": "LV2",
        "escalate_minutes": 30
        }
        ],
        "repeat_count": 2,
        "finish_condition": "ACKNOWLEDGED",
        "scope": "GLOBAL",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-21T09:22:45.340Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific EscalationPolicy. You can make changes in EscalationPolicy settings, including the name, the escalation process, and the number of iterations.
        request_example: >-
        {
        "escalation_policy_id": "ep-526e536fdca9",
        "name": "es-test2",
        "rules": [{"notification_level": "LV1", "escalate_minutes": 15},
        {"notification_level": "LV2", "escalate_minutes": 15},
        {"notification_level": "LV3", "escalate_minutes": 15}],
        "repeat_count": 1,
        "finish_condition": "RESOLVED",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "escalation_policy_id": "ep-526e536fdca9",
        "name": "es-test2",
        "rules": [
        {
        "notification_level": "LV1",
        "escalate_minutes": 15
        },
        {
        "notification_level": "LV2",
        "escalate_minutes": 15
        },
        {
        "notification_level": "LV3",
        "escalate_minutes": 15
        }
        ],
        "repeat_count": 1,
        "finish_condition": "RESOLVED",
        "scope": "GLOBAL",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-21T09:22:45.340Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_default(self, request, context):
        """
        desc: Sets a specific EscalationPolicy as default. Only policies configured as global can be set as default. When a Project is created, even if you did not configure any policy to the Project, the default policy set by this api method is applied.
        request_example: >-
        {
        "escalation_policy_id": "ep-526e536fdca9",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "escalation_policy_id": "ep-526e536fdca9",
        "name": "es-test2",
        "is_default": true,
        "rules": [
        {
        "notification_level": "LV1",
        "escalate_minutes": 15
        },
        {
        "notification_level": "LV2",
        "escalate_minutes": 15
        },
        {
        "notification_level": "LV3",
        "escalate_minutes": 15
        }
        ],
        "repeat_count": 1,
        "finish_condition": "RESOLVED",
        "scope": "GLOBAL",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-21T09:22:45.340Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific EscalationPolicy. Deletes the EscalationPolicy with the escalation_policy_id from the deletion request.
        request_example: >-
        {
        "escalation_policy_id": "ep-d75670166af4",
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific EscalationPolicy. Prints detailed information about the EscalationPolicy, including the name, rules, and termination conditions.
        request_example: >-
        {
        "escalation_policy_id": "ep-d75670166af4",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "escalation_policy_id": "ep-d75670166af4",
        "name": "0525-ms-test-2",
        "rules": [
        {
        "notification_level": "LV2",
        "escalate_minutes": 30
        },
        {
        "notification_level": "LV2"
        }
        ],
        "finish_condition": "ACKNOWLEDGED",
        "scope": "GLOBAL",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-25T09:31:38.573Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all EscalationPolicies. You can use a query to get a filtered list of EscalationPolicies.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "results": [
        {
        "escalation_policy_id": "ep-7c9745003372",
        "name": "0525-ms-test-1",
        "rules": [
        {
        "notification_level": "LV1"
        }
        ],
        "finish_condition": "ACKNOWLEDGED",
        "scope": "GLOBAL",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-25T09:31:15.150Z"
        },
        {
        "escalation_policy_id": "ep-d75670166af4",
        "name": "0525-ms-test-2",
        "rules": [
        {
        "notification_level": "LV2",
        "escalate_minutes": 30
        },
        {
        "notification_level": "LV2"
        }
        ],
        "finish_condition": "ACKNOWLEDGED",
        "scope": "GLOBAL",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-25T09:31:38.573Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EscalationPolicyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.CreateEscalationPolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.UpdateEscalationPolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.SerializeToString,
            ),
            'set_default': grpc.unary_unary_rpc_method_handler(
                    servicer.set_default,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.GetEscalationPolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPoliciesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.EscalationPolicy', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EscalationPolicy(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.CreateEscalationPolicyRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.UpdateEscalationPolicyRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_default(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/set_default',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/delete',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.GetEscalationPolicyRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPoliciesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.EscalationPolicy/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2.EscalationPolicyStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/config/v1/domain_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/config/v1/domain_config.proto\x12\x16spaceone.api.config.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x87\x01\n\x16SetDomainConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"6\n\x13\x44omainConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"G\n\x16GetDomainConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"`\n\x11\x44omainConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\xa9\x01\n\x10\x44omainConfigInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\nupdated_at\x18\x06 \x01(\t\"c\n\x11\x44omainConfigsInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.config.v1.DomainConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15\x44omainConfigStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xcd\x07\n\x0c\x44omainConfig\x12\x85\x01\n\x06\x63reate\x12..spaceone.api.config.v1.SetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/config/v1/domain-configs\x12\x8b\x01\n\x06update\x12..spaceone.api.config.v1.SetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/config/v1/domain-config/{name}\x12\x88\x01\n\x03set\x12..spaceone.api.config.v1.SetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/config/v1/domain-config/{name}\x12v\n\x06\x64\x65lete\x12+.spaceone.api.config.v1.DomainConfigRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/config/v1/domain-config/{name}\x12\x88\x01\n\x03get\x12..spaceone.api.config.v1.GetDomainConfigRequest\x1a(.spaceone.api.config.v1.DomainConfigInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/config/v1/domain-config/{name}\x12\xa1\x01\n\x04list\x12).spaceone.api.config.v1.DomainConfigQuery\x1a).spaceone.api.config.v1.DomainConfigsInfo\"C\x82\xd3\xe4\x93\x02=\x12\x18/config/v1/domain-configZ!\"\x1f/config/v1/domain-config/search\x12u\n\x04stat\x12-.spaceone.api.config.v1.DomainConfigStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/config/v1/domain-config/statb\x06proto3')



_SETDOMAINCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetDomainConfigRequest']
_DOMAINCONFIGREQUEST = DESCRIPTOR.message_types_by_name['DomainConfigRequest']
_GETDOMAINCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetDomainConfigRequest']
_DOMAINCONFIGQUERY = DESCRIPTOR.message_types_by_name['DomainConfigQuery']
_DOMAINCONFIGINFO = DESCRIPTOR.message_types_by_name['DomainConfigInfo']
_DOMAINCONFIGSINFO = DESCRIPTOR.message_types_by_name['DomainConfigsInfo']
_DOMAINCONFIGSTATQUERY = DESCRIPTOR.message_types_by_name['DomainConfigStatQuery']
SetDomainConfigRequest = _reflection.GeneratedProtocolMessageType('SetDomainConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDOMAINCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.SetDomainConfigRequest)
  })
_sym_db.RegisterMessage(SetDomainConfigRequest)

DomainConfigRequest = _reflection.GeneratedProtocolMessageType('DomainConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigRequest)
  })
_sym_db.RegisterMessage(DomainConfigRequest)

GetDomainConfigRequest = _reflection.GeneratedProtocolMessageType('GetDomainConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.GetDomainConfigRequest)
  })
_sym_db.RegisterMessage(GetDomainConfigRequest)

DomainConfigQuery = _reflection.GeneratedProtocolMessageType('DomainConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGQUERY,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigQuery)
  })
_sym_db.RegisterMessage(DomainConfigQuery)

DomainConfigInfo = _reflection.GeneratedProtocolMessageType('DomainConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGINFO,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigInfo)
  })
_sym_db.RegisterMessage(DomainConfigInfo)

DomainConfigsInfo = _reflection.GeneratedProtocolMessageType('DomainConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGSINFO,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigsInfo)
  })
_sym_db.RegisterMessage(DomainConfigsInfo)

DomainConfigStatQuery = _reflection.GeneratedProtocolMessageType('DomainConfigStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINCONFIGSTATQUERY,
  '__module__' : 'spaceone.api.config.v1.domain_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.DomainConfigStatQuery)
  })
_sym_db.RegisterMessage(DomainConfigStatQuery)

_DOMAINCONFIG = DESCRIPTOR.services_by_name['DomainConfig']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINCONFIG.methods_by_name['create']._options = None
  _DOMAINCONFIG.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\033\"\031/config/v1/domain-configs'
  _DOMAINCONFIG.methods_by_name['update']._options = None
  _DOMAINCONFIG.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['set']._options = None
  _DOMAINCONFIG.methods_by_name['set']._serialized_options = b'\202\323\344\223\002!\"\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['delete']._options = None
  _DOMAINCONFIG.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['get']._options = None
  _DOMAINCONFIG.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/config/v1/domain-config/{name}'
  _DOMAINCONFIG.methods_by_name['list']._options = None
  _DOMAINCONFIG.methods_by_name['list']._serialized_options = b'\202\323\344\223\002=\022\030/config/v1/domain-configZ!\"\037/config/v1/domain-config/search'
  _DOMAINCONFIG.methods_by_name['stat']._options = None
  _DOMAINCONFIG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/config/v1/domain-config/stat'
  _SETDOMAINCONFIGREQUEST._serialized_start=194
  _SETDOMAINCONFIGREQUEST._serialized_end=329
  _DOMAINCONFIGREQUEST._serialized_start=331
  _DOMAINCONFIGREQUEST._serialized_end=385
  _GETDOMAINCONFIGREQUEST._serialized_start=387
  _GETDOMAINCONFIGREQUEST._serialized_end=458
  _DOMAINCONFIGQUERY._serialized_start=460
  _DOMAINCONFIGQUERY._serialized_end=556
  _DOMAINCONFIGINFO._serialized_start=559
  _DOMAINCONFIGINFO._serialized_end=728
  _DOMAINCONFIGSINFO._serialized_start=730
  _DOMAINCONFIGSINFO._serialized_end=829
  _DOMAINCONFIGSTATQUERY._serialized_start=831
  _DOMAINCONFIGSTATQUERY._serialized_end=927
  _DOMAINCONFIG._serialized_start=930
  _DOMAINCONFIG._serialized_end=1903
# @@protoc_insertion_point(module_scope)
